@@ -7,19 +7,23 @@ pub struct Config {
     pub refresh_rate: usize,
     pub frequency_scale_range: [usize; 2],
     pub frequency_scale_amount: usize,
-    pub bar_reduction: usize,
+    pub density_reduction: usize,
+    pub max_frequency: usize,
+    pub volume: f32,
 }
 impl Default for Config {
     fn default() -> Self {
         Config { 
-            buffering: 10,
-            smoothing_size: 15,
-            smoothing_amount: 3,
+            buffering: 5,
+            smoothing_size: 5,
+            smoothing_amount: 5,
             resolution: 3000,
             refresh_rate: 60,
             frequency_scale_range: [0, 3500],
-            frequency_scale_amount: 2,
-            bar_reduction: 2,
+            frequency_scale_amount: 3,
+            density_reduction: 10,
+            max_frequency: 20_000,
+            volume: 1.0,
         }
     }
 }
\ No newline at end of file
